# opisense_client

## Intro
Python package providing some functions to interact with the Opisense API. 
More info about Opisense at www.opisense.com

## Warning
This is a first version to be tested by the users

## Changelog

